"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cross_helpers_1 = require("@graphql-mesh/cross-helpers");
const redis_1 = require("@upstash/redis");
const disposablestack_1 = require("@whatwg-node/disposablestack");
class UpstashRedisCache {
    constructor(config) {
        this.abortCtrl = new AbortController();
        this.redis = new redis_1.Redis({
            url: cross_helpers_1.process.env.UPSTASH_REDIS_REST_URL,
            token: cross_helpers_1.process.env.UPSTASH_REDIS_REST_TOKEN,
            enableAutoPipelining: true,
            signal: this.abortCtrl.signal,
            latencyLogging: !!cross_helpers_1.process.env.DEBUG,
            ...config,
        });
    }
    get(key) {
        return this.redis.get(key);
    }
    async set(key, value, options) {
        if (options?.ttl) {
            await this.redis.set(key, value, {
                px: options.ttl * 1000,
            });
        }
        else {
            await this.redis.set(key, value);
        }
    }
    async delete(key) {
        const num = await this.redis.del(key);
        return num > 0;
    }
    getKeysByPrefix(prefix) {
        return this.redis.keys(prefix + '*');
    }
    [disposablestack_1.DisposableSymbols.dispose]() {
        return this.abortCtrl.abort();
    }
}
exports.default = UpstashRedisCache;
